ComputeShaders
**************

.. currentmodule:: ModernGL

.. automethod:: Context.compute_shader
	:noindex:

.. autoclass:: ComputeShader
	:members: source, uniforms, uniform_blocks

	.. automethod:: run(group_x=1, group_y=1, group_z=1)

.. toctree::
	:maxdepth: 4
